@@ -1,11 +1,11 @@
 package Tapper::Benchmark;
-# git description: v0.007-2-g8dfd310
+# git description: v0.008-6-ga69edb6
 
 BEGIN {
   $Tapper::Benchmark::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$Tapper::Benchmark::VERSION = '0.008';
+$Tapper::Benchmark::VERSION = '0.009';
 use strict;
 use warnings;
 
@@ -147,6 +147,7 @@ sub new {
     else {
         $or_self->{query} = $s_module->new({
             dbh    => $hr_atts->{dbh},
+            driver => $hr_atts->{dbh}{Driver}{Name},
             debug  => $hr_atts->{debug} || 0,
             config => $or_self->{config},
         });
@@ -368,18 +369,25 @@ sub process_queued_multi_benchmark {
     my $ar_data_points;
     my $ar_results;
     my $or_result;
+    my $driver = $or_self->{query}{driver};
 
     # ===== exclusively pick single raw entry =====
     # Lock single row via processing=1 so that only one worker handles it!
+    $or_self->{query}{dbh}->do("set transaction isolation level read committed") if $driver eq "mysql"; # avoid deadlocks due to gap locking
     $or_self->{query}->start_transaction;
     eval {
             $ar_results = $or_self->{query}->select_raw_bench_bundle_for_lock;
             $or_result  = $ar_results->fetchrow_hashref;
             $i_id       = $or_result->{raw_bench_bundle_id};
-            goto RETURN unless $i_id;
+            if (!$i_id) {
+                    $or_self->{query}->finish_transaction( $@ );
+                    $or_self->{query}{dbh}->do("set transaction isolation level repeatable read") if $driver eq "mysql"; # reset to normal gap locking
+                    goto RETURN ;
+            }
             $or_self->{query}->start_processing_raw_bench_bundle($i_id);
     };
     $or_self->{query}->finish_transaction( $@ );
+    $or_self->{query}{dbh}->do("set transaction isolation level repeatable read") if $driver eq "mysql"; # reset to normal gap locking
 
     # ===== process that single raw entry =====
     $or_self->{query}->start_transaction;
@@ -406,9 +414,7 @@ sub gc {
 
     my ( $or_self, $hr_options ) = @_;
 
-    $or_self->{query}->start_transaction;
     $or_self->{query}->delete_processed_raw_bench_bundles;
-    $or_self->{query}->finish_transaction( $@ );
 }
 
 sub add_multi_benchmark {
