@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Benchmark::Query::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Tapper::Benchmark - querying - base class
-$Tapper::Benchmark::Query::VERSION = '0.008';
+$Tapper::Benchmark::Query::VERSION = '0.009';
 use strict;
 use warnings;
 use Digest::MD5;
@@ -70,7 +70,7 @@ sub start_transaction {
     local $or_self->{dbh}{RaiseError} = 1;
 
     eval {
-        push @{$or_self->{old_AutoCommit}}, $or_self->{dbh}{AutoCommit}; # allow nested transactions (does this make sense)
+        $or_self->{old_AutoCommit} = $or_self->{dbh}{AutoCommit};
         $or_self->{dbh}{AutoCommit} = 0;
     };
     if ( $@ ) {
@@ -104,8 +104,7 @@ sub finish_transaction {
             $or_self->{dbh}->commit();
         }
 
-        my $old_AutoCommits = $or_self->{old_AutoCommit}; # reference, to change it
-        $or_self->{dbh}{AutoCommit} = pop @$old_AutoCommits if @$old_AutoCommits;
+        $or_self->{dbh}{AutoCommit} = $or_self->{old_AutoCommit};
 
     }
 
